-- Copyright (c) 2011 Cloudera, Inc. All rights reserved.
--
-- Version 6 of the CMON schema. Following changes are made:
--
-- 1. Add index to TS column of table CMON_LONG_LIVED_DATA_POINTS_HOURLY,
-- this makes it same as indexes on table CMON_LONG_LIVED_DATA_POINTS.
-- 2. Rename table CMON_LONG_LIVED_DATA_POINTS to CMON_LONG_LIVED_DATA_POINTS_YYYY_MM_DD,
--    this is needed as part of poor man's partitioning of this table.
-- 3. Add table CMON_PARTITION_INFO for storing information about partitions.
-- 4. Leave an empty CMON_LONG_LIVED_DATA_POINTS table to serve as a prototype
--    for future partitioned tables.

UPDATE CMON_SCHEMA_VERSION SET VERSION=6;

-- Create an index on summary table so that data can be deleted by timestamp
CREATE INDEX IDX_SUMMARY_CALC ON CMON_LONG_LIVED_DATA_POINTS_HOURLY(TS);

-- Create table to hold partition info
CREATE TABLE CMON_PARTITION_INFO (
  ID bigint NOT NULL AUTO_INCREMENT,
  NAME varchar(80) NOT NULL,
  BASE_TABLE varchar(80) NOT NULL,
  END_TS bigint NOT NULL,
  PRIMARY KEY (ID)
) ENGINE=InnoDB;
CREATE UNIQUE INDEX PARTITION_NAME ON CMON_PARTITION_INFO (NAME);

-- Now rename existing CMON_LONG_LIVED_DATA_POINTS table
-- We will need an empty table to serve as a prototype for new tables
-- So before renaming create a new prototype table
--
-- NOTE: "Create Table Like" doesn't copy foreign key constraints. This apparently
-- is a feature and not a bug, see: http://bugs.mysql.com/bug.php?id=35526
-- But as of Mar 2012 we have already release this version of schema. Thus the
-- foreign key fix goes in 00007_cmon_schema.mysql.ddl

CREATE TABLE CMON_LONG_LIVED_DATA_POINTS_PROTOTYPE LIKE CMON_LONG_LIVED_DATA_POINTS;

set @current_time = UNIX_TIMESTAMP(date_add(curdate(), interval 1 day)) * 1000;
set @date_suffix = DATE_FORMAT(CURDATE(), '%Y_%m_%d');
set @new_table_name = concat("CMON_LONG_LIVED_DATA_POINTS_", @date_suffix);
set @rename_sql = concat("RENAME TABLE CMON_LONG_LIVED_DATA_POINTS TO ", @new_table_name);

PREPARE stmt FROM @rename_sql;
EXECUTE stmt;
DEALLOCATE PREPARE stmt;

RENAME TABLE CMON_LONG_LIVED_DATA_POINTS_PROTOTYPE TO CMON_LONG_LIVED_DATA_POINTS;

-- Now insert appropriate record in the CMON_PARTITION_INFO table
INSERT INTO CMON_PARTITION_INFO (NAME, BASE_TABLE, END_TS)
  VALUES (@new_table_name, "CMON_LONG_LIVED_DATA_POINTS", @current_time);
